<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 3, 2013 10:45:57 AM
 * @version $Rev$
 */

/**
 * Job class
 * Used to ....
 */
class Frontend_Job {

    private $interfacer = null;
    private $properties = array();
    private $source = null;
    private $publication_id = 0;
    private $labels = array();

    public function __construct($properties) {


        $this->interfacer = WP_Interfacer::getInstance();
        $this->properties = $properties;

        $job_id_property = '_carerix_job';
        $promotional_id_property = '_carerix_promotional';

        if ($this->interfacer->wpml_is_active()) {
            $job_id_property .= '_' . $this->interfacer->language_major_current();
        }

        if (isset($this->properties[$job_id_property])) {
            $this->publication_id = $this->properties[$job_id_property][0];
        }

        if (isset($this->properties[$promotional_id_property])) {
            $this->publication_id = $this->properties[$promotional_id_property][0];
        }

        if (!$this->publication_id) {
            $this->publication_id = @$this->properties['guid'][0];
        }

        $this->labels = Utils_Labels::get();
    }

    public function getSource() {
        $source = false;
        if ($this->source)
            return $this->source;

        if (isset($this->properties['source'])) {
            $source_id = $this->properties['source'][0];
        }

        if ($source_id) {
            $jobSource = new Entity_Source_Job($source_id);
            $source = $jobSource->getData();
            $source['settings'] = unserialize($source['settings']);
            if (!isset($source['settings']['apply_button_bottom']) && !isset($source['settings']['apply_button_top'])) {
                $source['settings']['apply_button_bottom'] = 'on';
            }
            $this->source = $source;
            return $source;
        }
        return $source;
    }

    public function display($content) {
        $backtrace = debug_backtrace();

        foreach ($backtrace as $bkt) {
            if (isset($bkt['file'])) {
                if (basename($bkt['file']) == 'widgets.php')
                    return $content;
            }
        }

        if (!$this->interfacer->frontend_displayed_single()) {
            $posStart = stripos($content, "<h4 class='cx_h4'");
            $posEnd = stripos($content, '</h4>');
            if ($posStart === 0) {
                $content = trim(substr($content, $posEnd + strlen('</h4>')));
            }

            return $content;
        }

        $post_permalink = $this->interfacer->get_post_permalink();
        $labels = Utils_Labels::get();
        $back_link = '<a href="' . $post_permalink . '">' . $labels['CxPortal.button.backToJobDetails'] . '</a>';
        if (isset($_GET['apply']) && $_GET['apply'] == 'true') {
            // safe guarding from get_the_excerpt function when used by YOAST plugin if in an apply form;
            foreach ($backtrace as $bkt) {
                if (isset($bkt['file'])) {
                    if (basename($bkt['file']) == 'class-frontend.php')
                        return '';
                }
            }

            $jobSource = $this->getSource();

            if (isset($jobSource['settings']['apply_form'])) {
                $form_id = (int) $jobSource['settings']['apply_form'];
            } else {
                // get the default form if one was not set;
                $formsTable = new WP_Table(Environment_Installation::TABLE_FORMS);
                $all_forms = $formsTable->getAll();
                foreach ($all_forms as $form) {
                    $form_settings = unserialize($form['settings']);

                    if (isset($form_settings['is_default'])) {
                        $form_id = (int) $form['id'];
                        break;
                    }
                }
            }

            if (!$form_id) {
                echo '<span style="color: red;"> There is no form in the database </span>';
                return;
            }

            $formSource = new Entity_Form($form_id);
            $formData = $formSource->getData();
            $formData['settings'] = unserialize($formData['settings']);

            Entity_Form_EmployeeApply::display($formData['settings'], $this->publication_id);
            return $back_link;
        }

        if (isset($_GET['tellafriend'])) {
            $form = new Entity_Form_TellAFriend($this->publication_id);
            $form->display();
            return $back_link;
        }

        if (isset($_GET['subscribe'])) {
            $form = new Entity_Form_Subscribe($this->publication_id);
            $form->display();
            return $back_link;
        }

        if (isset($_GET['login'])) {
            $form = new Entity_Form_Login();
            $form->display();

            return $back_link;
        }

        if (isset($_GET['forgot'])) {
            $form = new Entity_Form_ForgotPassword();
            $form->display();
            return $back_link;
        }

        if (isset($_GET['apply_mode'])) {
            $apply_mode = new Utils_Template('fragments/frontend/apply_mode');
            $apply_link = $this->interfacer->get_post_permalink(false, 'apply=true');
            return '<form method="post" enctype="multipart/form-data" action="' . $apply_link . '">' . $apply_mode->display(true) . '</form>';
        }

        if (isset($_GET['logout'])) {
            unset($_SESSION['logged_in']);
            unset($_SESSION['employee_id']);
        }

        $header = $this->get_header();
        $subheader = $this->get_subheader();
        $footer = $this->get_footer();
        return $header . $subheader . $content . $footer;
    }

    private function get_subheader() {
        return '';
        $social_icons = $this->get_social_icons('top');
        $apply_link = $this->get_apply_link('top');
        $content = '<div>' . $apply_link . $social_icons;
        $content .= '</div>';
        return $content;
    }

    private function get_header() {

        if (Environment_Settings::getLoginLinkStatus() == 'on')
            return;

        if ($this->interfacer->frontend_displayed_single() === FALSE && $this->interfacer->frontend_displayed_page() === FALSE) {
            return;
        }

        $data = array();
        if (isset($_SESSION['logged_in']) && $_SESSION['logged_in'] === TRUE) {
            $data['name'] = $_SESSION['name'];
            $data['logout_link'] = $this->interfacer->get_post_permalink(false, 'logout=true');
            $template_fragment = 'fragments/frontend/logged_in';
        } else {
            $data['login'] = $this->interfacer->get_post_permalink(false, 'login=true');
            $template_fragment = 'fragments/frontend/logged_out';
        }
        $template = new Utils_Template($template_fragment);
        $template->with($data)->display();
    }

    private function get_footer() {
        return;
        if ($this->interfacer->frontend_displayed_single() === FALSE && $this->interfacer->frontend_displayed_page() === FALSE) {
            return;
        }

        $brief = $this->get_brief();
        $apply_link = $this->get_apply_link('bottom');
        $rss_link = $this->get_rss_link();
        $tell_a_friend_link = $this->get_tell_a_friend_link();
        $print_link = $this->get_print_link();
        $social_icons = $this->get_social_icons('bottom');
        $job_alert_subscription = $this->get_job_alert_subscription_link();

        $content = '<div>' . $apply_link
                . $brief
                . $rss_link
                . $tell_a_friend_link
                . $job_alert_subscription
                . $print_link
                . $social_icons . '</div>';

        return $content;
    }

    private function get_apply_link($type) {
        $jobSource = $this->getSource();
        if (isset($jobSource['settings']['apply_button_' . $type])) {
            $post_permalink = $this->interfacer->get_post_permalink(false, 'apply=true');
            return "<div><a id='apply_button' href='$post_permalink'>{$this->labels['general.button.apply']}</a></div>";
        }
        return '';
    }

    private function get_rss_link() {
        $jobSource = $this->getSource();
        $div = '';

        if (isset($jobSource['settings']['rss_link'])) {
            $category = get_the_category();
            $category_name = '';
            $term_id = 0;

            if (isset($category[0])) {
                $term = $category[0];
                $term_id = $term->term_id;
                $category_name = $term->name;
            }

            $feedgeneral = get_category_feed_link($term_id);

            $div = "<div class='rss'><a id='carerix_rss_link' target='_blank' rel='nofollow' href='{$feedgeneral}'>{$this->labels['CxPortal.message.field.rss']} $category_name</a></div>";
        }

        if (isset($jobSource['settings']['rss_link_all'])) {
            $categoryLanguage = $this->interfacer->language_major_current();
            $labels = Utils_Labels::get($this->categoryLanguage);
            $resource = 'resource_category_' . str_replace('.', '_', 'general.header.publications');
            $categoryKey = Environment_Settings::_setting_get($resource . '_' . $categoryLanguage);

            if (!$categoryKey)
                $categoryKey = $labels[$resource];
            $term = get_term_by('name', $categoryKey, 'category');
            //$url = get_bloginfo('wpurl') .'/publications_rss'; 

            $url = get_category_feed_link(@$term->term_id);

            $div .= "<div class='rss_all'><a id='carerix_rss_link_all' target='_blank' rel='nofollow' href='$url'>{$this->labels['CxPortal.message.field.rssAll']}</a></div>";
        }

        return $div;
    }

    private function get_tell_a_friend_link() {
        $link = $this->interfacer->get_post_permalink(false, 'tellafriend');
        $jobSource = $this->getSource();
        $div = '';

        if (isset($jobSource['settings']['tell_a_friend_link'])) {
            $div = "<div class='tell_a_friend'><a id='carerix_tellafriend_link' rel='nofollow' href='$link'>{$this->labels['CxPortal.header.tellAFriendTitle']}</a></div>";
        }

        return $div;
    }

    private function get_print_link() {
        $jobSource = $this->getSource();
        $div = '';
        if (isset($jobSource['settings']['print_link'])) {
            $link = $this->interfacer->get_post_permalink(false, 'print');
            //$div = "<div class='print'><a id='carerix_print_link' rel='nofollow' href='#' onclick='window.open(\"$link\", \"print\", \"height=600,width=800\")  '>{$this->labels['general.button.print']}</a></div>";	
            $div = "<div class='print'><a id='carerix_print_link' rel='nofollow' href='#' onclick='window.print();  '>{$this->labels['general.button.print']}</a></div>";
        }

        return $div;
    }

    private function get_brief() {
        $jobSource = $this->getSource();
        $div = '';

        $general_exception = false;
        try {

            if (isset($jobSource['settings']['brief_section'])) {
                $params = array('show' => array('toVacancy', 'toVacancy.toFunctionLevel1.value', 'toVacancy.toFunctionLevel2.value', 'toVacancy.toFunctionLevel3.value', 'publicationID'));

                $publication = Carerix_Api_Rest_Entity_CRPublication::find($this->publication_id, $params);

                $labels = Utils_Labels::get();

                if (isset($jobSource['settings']['brief_section_function_group'])) {
                    $functionGroup = implode(' / ', array_filter(array(
                        $publication->toVacancy->toFunctionLevel1->value,
                        $publication->toVacancy->toFunctionLevel2->value,
                        $publication->toVacancy->toFunctionLevel3->value
                    )));
                    if ($functionGroup)
                        $div .= "<div id='carerix_function_group'><strong>{$labels['CxPortal.message.field.functionGroup']}:</strong> $functionGroup</div>";
                }

                if (isset($jobSource['settings']['brief_section_vacancy_id'])) {
                    $div .= "<div id='carerix_vacancy_id'><strong>{$labels['general.header.jobID']}:</strong> #{$publication->toVacancy->vacancyID} </div>";
                }
            }
        } catch (Carerix_Api_Rest_Exception $care) {
            $general_exception = $care;
        } catch (Exception $ex) {
            $general_exception = $ex;
        }
        if ($general_exception) {
            Utils_Log::write(Utils_Log::TYPE_FETCH_PUBLICATION, $publication, $general_exception);
        }

        return $div;
    }

    private function get_social_icons($type) {
        // $type can be 'bottom' or 'top'
        $jobSource = $this->getSource();
        $div = '';

        if (isset($jobSource['settings']['social_icons_' . $type])) {
            $div = "<div class='social_icons'>
						<div id='cx_socials'>
							<span class='st_facebook' ></span><span class='st_twitter' ></span>					
                            <span class='st_linkedin' ></span><span class='st_email' ></span>
						</div>
                        <script type='text/javascript'>var switchTo5x=true;</script>
						<script type='text/javascript' src='http://w.sharethis.com/button/buttons.js'></script>
                        <script type='text/javascript'>stLight.options({publisher: '9b61bbc7-5b60-40a2-9ea9-36c8b84e5406', doNotHash: false, doNotCopy: false, hashAddressBar: false});</script>
						
                    </div>";
        }
        return $div;
    }

    private function get_job_alert_subscription_link() {
        $link = $this->interfacer->get_post_permalink(false, 'subscribe');
        $jobSource = $this->getSource();
        $div = '';

        if (isset($jobSource['settings']['job_alert_subscription'])) {
            $div = "<div class='apply'><a id='carerix_jas_link' rel='nofollow' href='$link'>{$this->labels['general.button.subscribeJobAlert']}</a></div>";
        }
        return $div;
    }

}
